# Makefile for DKB Ray Tracing Program by David Buck and Aaron Collins
# Unix Makefile, modified for MPW by Thomas Okken
# This file is released to the public domain.

#***************************************************************
#*
#*                      MPW MakeFile
#*
#***************************************************************

LINK_FLAGS = -w -ra =20
C_FLAGS_DKB = -w -b2 -mc68020 -mc68881 -elems881
C_FLAGS_MAC = -w -b2 -mc68881 -elems881

LIBS =		"{CLibraries}"CLib881.o "{CLibraries}"StdCLib.o 
			"{CLibraries}"CRuntime.o "{CLibraries}"CSANELib881.o 
			"{CLibraries}"Math881.o "{CLibraries}"CInterface.o 
			"{Libraries}"Interface.o "{Libraries}"Runtime.o

DKBOBJS =	trace.c.o render.c.o tokenize.c.o parse.c.o 
			objects.c.o spheres.c.o quadrics.c.o lighting.c.o 
			prioq.c.o texture.c.o matrices.c.o csg.c.o dump.c.o 
			colour.c.o viewpnt.c.o ray.c.o planes.c.o iff.c.o 
			gif.c.o gifdecod.c.o triangle.c.o raw.c.o targa.c.o 
			quartics.c.o vect.c.o mac_mpw.c.o

DKBTrace  mac_mpw.r mac_mpw.rsrc
	Rez -a -o DKBTrace mac_mpw.r
	SetFile -t APPL -c dkbT -a Bi DKBTrace
DKBTrace  {DKBOBJS}
	Link -o DKBTrace {LINK_FLAGS} {DKBOBJS} {LIBS}

trace.c.o  trace.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} trace.c
render.c.o  render.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} render.c
tokenize.c.o  tokenize.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} tokenize.c
parse.c.o  parse.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg2 parse.c
objects.c.o  objects.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} objects.c
spheres.c.o  spheres.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} spheres.c
quadrics.c.o  quadrics.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg2 quadrics.c
lighting.c.o  lighting.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg2 lighting.c
prioq.c.o  prioq.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg3 prioq.c
texture.c.o  texture.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg3 texture.c
matrices.c.o  matrices.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg3 matrices.c
csg.c.o  csg.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg3 csg.c
dump.c.o  dump.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg3 dump.c
colour.c.o  colour.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg3 colour.c
viewpnt.c.o  viewpnt.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg3 viewpnt.c
ray.c.o  ray.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg3 ray.c
planes.c.o  planes.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg3 planes.c
iff.c.o  iff.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg3 iff.c
gif.c.o  gif.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg4 gif.c
gifdecod.c.o  gifdecod.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg4 gifdecod.c
triangle.c.o  triangle.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg4 triangle.c
raw.c.o 	raw.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg4 raw.c
targa.c.o  targa.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg4 targa.c
quartics.c.o  quartics.c dkbproto.h frame.h vector.h config.h
	C {C_FLAGS_DKB} -s Seg4 quartics.c
vect.c.o  vect.c dkbproto.h frame.h config.h
	C {C_FLAGS_DKB} -s Seg4 vect.c
mac_mpw.c.o  mac_mpw.c dkbproto.h frame.h config.h
	C {C_FLAGS_MAC} -s Seg5 mac_mpw.c
